@@ -60,11 +60,13 @@ private slots:
     void onScanModeChanged(int index);
     void onScanFinished(const QImage &image);
     void handleDeviceError(const QString &error);
+    void onDeviceOpened();
 
 private:
     void setupUI();
     void connectDeviceSignals(bool bind);
     void updateDeviceSettings();
+    void resetPreview();
     QImage convertToBlackWhite(const QImage &sourceImage);
 
     DeviceBase* m_device = nullptr;
